@@ -31,7 +31,10 @@ def random_joke():
     print(response.text)
 
 def JOD():
-    print("What did the gun say when it fell down. Shoot!")
+    url = "https://jokes.one/joke-of-the-day/jod"
+    html_content = requests.get(url).text
+    soup = BeautifulSoup(html_content, "html.parser")
+    print(soup.find('p').text)
 
 def Multiple_Jokes(n):
     for i in range(n):
@@ -46,5 +49,21 @@ def sjoke(Joke_id):
     soup = BeautifulSoup(html_content, "html.parser")
     print(soup.find('p').text)
 
+def search_for_joke(Search_term):
+    url = f"https://icanhazdadjoke.com/search?term={Search_term}"
+    html_content = requests.get(url).text
+    soup = BeautifulSoup(html_content, "html.parser")
+    print(soup.find('td').text)
+
+def Random_knock_knock_joke():
+    import random
+    ran_int = random.randint(1, 148)
+    url = f"http://www.jokes4us.com/knockknockjokes/random/knockknock{ran_int}.html"
+    html_content = requests.get(url).text
+    soup = BeautifulSoup(html_content, "html.parser")
+    print(soup.find('font').text)
+    
+
 def version():
-    print("0.0.4")
+    print("1.1.1")
+
